==> gnuradio-docs-3.10.12.0-2-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GNU Radio C++ API Reference", "index.html", [
    [ "Build Instructions and Information", "build_guide.html", null ],
    [ "Components", "page_components.html", "page_components" ],
    [ "License", "License.html", null ],
    [ "Release Process Documentation", "page_releasing.html", [
      [ "Preparation", "page_releasing.html#Preparation", null ],
      [ "Tagging", "page_releasing.html#Release", null ],
      [ "Of Archives", "page_releasing.html#Creation", null ]
    ] ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", "namespacemembers_eval" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", "globals_vars" ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"ConstellationDisplayPlot_8h.html",
"agc3__cc__pydoc__template_8h.html#aabcda032df7125c695612afb25d50ba8",
"atsc__randomizer__pydoc__template_8h.html#a018632efca73ff7a5287cf52b1105135",
"block__detail__pydoc__template_8h.html#ad741dc3470cef825a67a4c4d9b4d92c9",
"build_2gr-blocks_2python_2blocks_2bindings_2pydoc__macros_8h.html#afa7cf06549cf7fd295f622ef6f376357",
"burst__tagger_8h_source.html",
"classConstellationDisplayForm.html#a2823ef966cee912b2cbf13984dc071dc",
"classDisplayPlot.html#adced30b44aac55b5473ed92a861c24bb",
"classFreqDisplayForm.html#ab059f732654e647ff50b2324ccfe28d8",
"classLineWidthMenu.html#a4e0fd0268d6b13d35c9e3c355c22a993",
"classTimeControlPanel.html#ae7362d583aff237d1a83a9474460f8d3",
"classVectorDisplayPlot.html#a419307004cdf3ba027691c0764f6dc04",
"classgr_1_1analog_1_1agc2__cc.html#a459b870507f8420157155e6bc64fcdd0",
"classgr_1_1analog_1_1kernel_1_1agc__ff.html#a752deb5e5d7635ef03556e6d430a887f",
"classgr_1_1basic__block.html#af3a5056e2de6b3e561c02f2de37de44c",
"classgr_1_1blocks_1_1and__blk.html",
"classgr_1_1blocks_1_1ctrlport__probe2__s.html",
"classgr_1_1blocks_1_1message__strobe__random.html#a0ff74a298e0cf409dabe63b14b99adba",
"classgr_1_1blocks_1_1tag__debug.html#a58d634fe5b124a3b842078b554fffdfc",
"classgr_1_1buffer__double__mapped.html#a4e581f90551a3ac5de1d7425b7b055a5",
"classgr_1_1digital_1_1adaptive__algorithm.html#a23536d8333087af0da113e0aff24f8ab",
"classgr_1_1digital_1_1constellation__bpsk.html#a80215bc28e7be4b0bb38b1b3a78654c0",
"classgr_1_1digital_1_1glfsr__source__b.html",
"classgr_1_1digital_1_1msk__timing__recovery__cc.html#acc57869ac653083218f25ded1cac4995",
"classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
"classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
"classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
"classgr_1_1fec_1_1tpc__decoder.html#a91ed2ddf6aa73eb271d6e8231f7cb815",
"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7c54ab3a48e8db3f8717a135be040db0",
"classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
"classgr_1_1filter_1_1single__pole__iir.html#aa8d14823d7649449309387443c133615",
"classgr_1_1iio_1_1device__sink.html#a04d0a5ca52ecd9cab96ffa858717cf05",
"classgr_1_1msg__accepter.html#a1032a8f3bf410b7670bc9af0c7c6d7ad",
"classgr_1_1qtgui_1_1ber__sink__b.html#a6a670553381933476126c820caa03a20",
"classgr_1_1qtgui_1_1eye__sink__f.html#ad0a17ef061f38d8e0adee502343d0a08",
"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f",
"classgr_1_1qtgui_1_1time__raster__sink__f.html#a6d9764d819fa106484ed54b40282960d",
"classgr_1_1qtgui_1_1vector__sink__f.html#a7cca97a9247ddbe46fab0a0cfea4c190",
"classgr_1_1soapy_1_1block.html#a2fa3ac00cebd970648557800316bcd1a",
"classgr_1_1trellis_1_1fsm.html",
"classgr_1_1uhd_1_1rfnoc__duc.html#a17bdf06529d229806eefed70149180cc",
"classgr_1_1vocoder_1_1alaw__decode__bs.html#aec1a4c451c9057ea31a318ae531c8a8c",
"classpmt_1_1pmt__base.html#a4dff1d4b51e49eb4474b3bb938b8e9b9",
"classrpcextractor__base.html#afb9a96dc63c5144792ca5e086476818f",
"complex__to__mag__squared__pydoc__template_8h_source.html",
"conv__bit__corr__bb_8h_source.html",
"ctcss__squelch__ff__pydoc__template_8h.html#a2594ce1461b66a101d5d47aedaa86342",
"dictionary__logger__backend__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"dir_cd60c432b920e74905d47b61718dc7dc.html",
"dvbt2__miso__cc__pydoc__template_8h.html",
"eye__sink__c__pydoc__template_8h.html#a062b385f59b4106986ba7b3e0bd71970",
"file__meta__sink__pydoc__template_8h_source.html",
"flowgraph__pydoc__template_8h.html#ad1bcfc130291c9bb64e4c4541acb2131",
"fsm__pydoc__template_8h.html#afb324f1453815928e8dec8948e86509f",
"generic__encoder__pydoc__template_8h.html#af18094c36adcc0bfc2830ddb2349d9fd",
"group__block.html",
"high__res__timer__pydoc__template_8h_source.html",
"keep__one__in__n__pydoc__template_8h.html#a5d3710d877a0780ae05a08cc4f46f7f0",
"maxstar_8h.html#a07ef3fc3f5370c001c90157ab2a48390",
"mpsk__snr__est__pydoc__template_8h_source.html",
"namespacegr_1_1blocks.html#a21e4d3207da5c3cddd29a4c62bf620cc",
"namespacegr_1_1dtv.html#a35dea4c78a05851f4beae107d010e26aa18a52f58f0bc7633c6312093cebd8cd1",
"namespacegr_1_1msgport__names.html#af939ef2b99731c1ae4ff1ee7634bb6a6",
"namespacemembers_func_s.html",
"namespacepmt.html#ac90b0d5332abb3e6f7b0b551e2d62f50",
"or__blk_8h.html",
"pdu__pydoc__template_8h.html#a408e778d162b794cb1b848eea0c6f74b",
"pfb__clock__sync__ccf__pydoc__template_8h.html#ad228bee18ab1577b7359308766f5c474",
"pmt__pydoc__template_8h.html#a2da44031789ee1dbd382d23ca49c7991",
"pmt__serial__tags_8h.html#abdf3c401a44b88c89208285f00d6643fa8d646134d42cb6e0368b7552ecc5029a",
"probe__signal__v_8h.html",
"regenerate__bb__pydoc__template_8h.html#aaf3414624c4423f950b7c0f745ef0684",
"rfnoc__tx__radio__pydoc__template_8h.html#ac5c1a8bf4435de092cf9322c6678d8dd",
"short__to__float__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"squelch__base__ff__pydoc__template_8h_source.html",
"structrpcbasic__register__set.html#adbf33ec27b820ab61034ce25eb37723a",
"tagged__encoder__pydoc__template_8h.html#a6b30e811796a421e7fda4efde79d4523",
"time__raster__sink__f__pydoc__template_8h.html#af0c32f274377035d73f901e251d14a26",
"ulaw__decode__bs_8h_source.html",
"vector__sink__f__pydoc__template_8h.html#ac27d1f4dc1e53b72a8d65e8a0905f043"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';

==> gnuradio-docs-3.10.12.0-4-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GNU Radio C++ API Reference", "index.html", [
    [ "Build Instructions and Information", "build_guide.html", null ],
    [ "Components", "page_components.html", "page_components" ],
    [ "License", "License.html", null ],
    [ "Release Process Documentation", "page_releasing.html", [
      [ "Preparation", "page_releasing.html#Preparation", null ],
      [ "Tagging", "page_releasing.html#Release", null ],
      [ "Of Archives", "page_releasing.html#Creation", null ]
    ] ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", "namespacemembers_eval" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", "globals_vars" ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"ConstellationDisplayPlot_8h.html",
"agc3__cc__pydoc__template_8h.html#aabcda032df7125c695612afb25d50ba8",
"atsc__randomizer__pydoc__template_8h.html#a018632efca73ff7a5287cf52b1105135",
"block__detail__pydoc__template_8h.html#ad741dc3470cef825a67a4c4d9b4d92c9",
"build_2gr-blocks_2python_2blocks_2bindings_2pydoc__macros_8h.html#afa7cf06549cf7fd295f622ef6f376357",
"burst__tagger_8h_source.html",
"classConstellationDisplayForm.html#a2823ef966cee912b2cbf13984dc071dc",
"classDisplayPlot.html#adced30b44aac55b5473ed92a861c24bb",
"classFreqDisplayForm.html#ab059f732654e647ff50b2324ccfe28d8",
"classLineWidthMenu.html#a4e0fd0268d6b13d35c9e3c355c22a993",
"classTimeControlPanel.html#ae7362d583aff237d1a83a9474460f8d3",
"classVectorDisplayPlot.html#a419307004cdf3ba027691c0764f6dc04",
"classgr_1_1analog_1_1agc2__cc.html#a459b870507f8420157155e6bc64fcdd0",
"classgr_1_1analog_1_1kernel_1_1agc__ff.html#a752deb5e5d7635ef03556e6d430a887f",
"classgr_1_1basic__block.html#af3a5056e2de6b3e561c02f2de37de44c",
"classgr_1_1blocks_1_1and__blk.html",
"classgr_1_1blocks_1_1ctrlport__probe2__s.html",
"classgr_1_1blocks_1_1message__strobe__random.html#a0ff74a298e0cf409dabe63b14b99adba",
"classgr_1_1blocks_1_1tag__debug.html#a58d634fe5b124a3b842078b554fffdfc",
"classgr_1_1buffer__double__mapped.html#a4e581f90551a3ac5de1d7425b7b055a5",
"classgr_1_1digital_1_1adaptive__algorithm.html#a23536d8333087af0da113e0aff24f8ab",
"classgr_1_1digital_1_1constellation__bpsk.html#a80215bc28e7be4b0bb38b1b3a78654c0",
"classgr_1_1digital_1_1glfsr__source__b.html",
"classgr_1_1digital_1_1msk__timing__recovery__cc.html#acc57869ac653083218f25ded1cac4995",
"classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
"classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
"classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
"classgr_1_1fec_1_1tpc__decoder.html#a91ed2ddf6aa73eb271d6e8231f7cb815",
"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7c54ab3a48e8db3f8717a135be040db0",
"classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
"classgr_1_1filter_1_1single__pole__iir_3_01gr__complex_00_01i__type_00_01double_01_4.html",
"classgr_1_1iio_1_1device__source.html#adbbbd5fee5d4b2b2d00d0637301b88b7",
"classgr_1_1msg__endpoint.html",
"classgr_1_1qtgui_1_1ber__sink__b.html#ab6781079e44762c083009d967b27d797",
"classgr_1_1qtgui_1_1freq__sink__c.html",
"classgr_1_1qtgui_1_1histogram__sink__f.html#af9c42348178bb37d9d2716b77fa431ce",
"classgr_1_1qtgui_1_1time__raster__sink__f.html#aa6b740ee6f4b605d423d542a5f51cb53",
"classgr_1_1qtgui_1_1vector__sink__f.html#ab4acfe471289cea3d564594a59926e63",
"classgr_1_1soapy_1_1block.html#a460c4a105d445fffe41e5d46a5eb913e",
"classgr_1_1trellis_1_1fsm.html#ada8ac748ba79726207672df609f59d8b",
"classgr_1_1uhd_1_1rfnoc__graph.html#a49365b0f1647db3adca9f3e8c2a63741",
"classgr_1_1vocoder_1_1codec2.html#a4fb8331472faad41468ffdd68654e6f1a9ae88a1fbedbe773a14f0e90aaeb4092",
"classpmt_1_1pmt__base.html#a97bac3d60aa2f86fece6565f34fc4648",
"classrpcserver__base.html#ad393fa1b463721770fcb170d2bb0b2db",
"const__sink__c__pydoc__template_8h.html#adfffa9b9a797c17acd4451d9d394b4b2",
"correctiq__man__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"ctrlport__probe2__s__pydoc__template_8h.html#a0e6b224359d8835ed8f00dc37268648c",
"dir_163b61ceea2e02982ffc042218391854.html",
"divide_8h_source.html",
"dvbt__convolutional__deinterleaver__pydoc__template_8h.html#a4db011872acbc55eddcb60080f525de1",
"eye__sink__f__pydoc__template_8h.html#a8485b5d8ebb13d760584b46778a31bca",
"filterbank__pydoc__template_8h_source.html",
"fmdet__cf__pydoc__template_8h_source.html",
"functions_type_s.html",
"globals_e.html",
"gsm__fr__decode__ps_8h_source.html",
"host__buffer__copy__pydoc__template_8h.html#adf4a6cf5f48f264b1c280f0c3d8e89e9",
"ldpc__encoder__pydoc__template_8h.html#a06627acd79858c9dd873d87f2d4f7023",
"message__pydoc__template_8h.html#a90599fa0a366fa0a9001c488d852d61a",
"multiply__by__tag__value__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"namespacegr_1_1blocks.html#a92545f9390e438079b540545ce228944",
"namespacegr_1_1dtv.html#a6756f8e55d0cb81f6f1d5a0ba7807bc1a6b42dfeedde75c99f8786fbec208a2aa",
"namespacegr_1_1soapy.html",
"namespacepmt.html#a0f26f38e24c533a8476dfb993a2bc7a7",
"nlog10__ff_8h.html",
"packet__headergenerator__bb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"peak__detector2__fb__pydoc__template_8h.html#a40fd5e294ba7058a0f40d2da5f05e90a",
"pfb__synthesizer__ccf__pydoc__template_8h.html#a4ffc7528d08939b3c6652c578965bad5",
"pmt__pydoc__template_8h.html#a6a96b09b7b856ac58f4e025ab60e3d46",
"polar__decoder__common__pydoc__template_8h.html#a5d92c4c5d930831a74fd9dc089b0464e",
"pull__source__pydoc__template_8h.html#a18777fdfaea4ef8b4aec73efbfa55949",
"repetition__encoder__pydoc__template_8h_source.html",
"rotator__pydoc__template_8h.html#a94ca7787156825af12d59fac07c88732",
"single__pole__iir__pydoc__template_8h_source.html",
"streams__to__stream__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"structrpcpmtconverter_1_1to__pmt__s64vect__f.html#aa841e518fed84ce97e9c3d98fd886fd3",
"tags__strobe__pydoc__template_8h.html",
"time__sink__f__pydoc__template_8h.html#a66b112b842f2897887fa21773cf67c80",
"usrp__block__pydoc__template_8h.html#a4914886d0686d7ffeaf3a53ab944298b",
"waterfall__sink__c__pydoc__template_8h.html#a6941cae5cef7d4ddaae997c28dfa08db"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
